@@ -10,11 +10,9 @@
 #'
 #' @return [[data.frame]]
 format_counts <- function(data, id_colname, count_column = "Count") {
-  as.data.frame(
-    tidyr::spread(
-      data = data[, c(id_colname, "CodeClass", "Name", count_column)],
-      key = get(id_colname),
-      value = get(count_column)
-    )
+  data.table::dcast(
+    data = data.table::setDT(data),
+    formula = sprintf("CodeClass + Name ~ %s", id_colname),
+    value.var = count_column
   )
 }
